@@ -3,8 +3,8 @@
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.26 2008/02/17 17:24:33 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080217 $
+! Version::   $Id: dc_error.f90,v 1.27 2008-05-11 04:56:23 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080602 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -409,6 +409,9 @@ module dc_error
   ! -505    :: [ <b>HST_ENODEPENDTIME   </b> ] 
   !            <b></b> :: (<i>cause_c</i>) does not depend on time
   !
+  ! -506    :: [ <b>HST_EBADVARNAME   </b> ] 
+  !            <b></b> :: variable name (<i>cause_c</i>) is invalid
+  !
   !=== gt4f90io ξγĥΤͽ󤷤Ƥ륨顼
   !=== Reserved error codes for future extensions of gt4f90io
   !
@@ -517,6 +520,7 @@ module dc_error
   integer, parameter, public:: HST_EBADNAME       = -503
   integer, parameter, public:: HST_ENOTTERMGTHIST = -504
   integer, parameter, public:: HST_ENODEPENDTIME  = -505
+  integer, parameter, public:: HST_EBADVARNAME    = -506
 
   !
   ! -1000 ʲ: 桼
@@ -660,7 +664,8 @@ contains
       msg = ' GT_HISTORY correspond to (' // trim(cause_string) // ') is not terminated'
     case(HST_ENODEPENDTIME)
       msg = ' (' // trim(cause_string) // ') does not depend on time'
-
+    case(HST_EBADVARNAME)
+      msg = ' variable name (' // trim(cause_string) // ') is invalid'
       !
       !
       ! -1000 ʲ: 桼
